﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart;
using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 라인 1
        /// </summary>
        private Line line1;

        /// <summary>
        /// 라인 2
        /// </summary>
        private Line line2;

        /// <summary>
        /// 라인 3
        /// </summary>
        private Line line3;

        /// <summary>
        /// 라인 4
        /// </summary>
        private Line line4;

        /// <summary>
        /// 타이머
        /// </summary>
        private Timer timer;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Text = "Line 클래스 : 실시간 차트 만들기";

            this.animationCheckBox.Checked = true;

            this.tChart.Panel.Pen      = new ChartPen(Color.Black);
            this.tChart.Legend.Visible = false;

            #region 라인 1을 설정한다.

            this.line1 = new Line();

            this.line1.Color         = Color.FromArgb(68, 102, 163);
            this.line1.LinePen.Width = 2;

            this.tChart.Series.Add(this.line1);

            #endregion
            #region 라인 2를 설정한다.

            this.line2 = new Line();

            this.line2.Color         = Color.FromArgb(243, 156, 53);
            this.line2.LinePen.Width = 2;

            this.tChart.Series.Add(this.line2);

            #endregion
            #region 라인 3을 설정한다.

            this.line3 = new Line();

            this.line3.Color         = Color.FromArgb(241, 76, 20);
            this.line3.LinePen.Width = 2;

            this.tChart.Series.Add(this.line3);

            #endregion
            #region 라인 4를 설정한다.

            this.line4 = new Line();

            this.line4.Color         = Color.FromArgb(78, 151, 168);
            this.line4.LinePen.Width = 2;

            this.tChart.Series.Add(this.line4);

            #endregion
            #region 타이머를 설정한다.

            this.timer = new Timer();

            this.timer.Interval = 50;

            #endregion
            #region 이벤트를 설정한다.

            Load                                  += Form_Load;
            FormClosing                           += Form_FormClosing;
            this.animationCheckBox.CheckedChanged += animationCheckBox_CheckedChanged;
            this.threeDChechBox.CheckedChanged    += threeDChechBox_CheckedChanged;
            this.legendCheckBox.CheckedChanged    += legendCheckBox_CheckedChanged;
            this.timer.Tick                       += timer_Tick;

            #endregion
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.tChart.Axes.Bottom.Increment = 5;

            this.line1.Add(1000);
            this.line2.Add(1000);
            this.line3.Add(1000);
            this.line4.Add(1000);

            this.timer.Start();
        }

        #endregion
        #region 폼을 닫을 경우 처리하기 - Form_FormClosing(sender, e)

        /// <summary>
        /// 폼을 닫을 경우 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_FormClosing(object sender, FormClosingEventArgs e)
        {
            this.timer.Stop();
        }

        #endregion
        #region 애니메이션 체크 박스 체크 변경시 처리하기 - animationCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 애니메이션 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void animationCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.timer.Enabled = this.animationCheckBox.Checked;
        }

        #endregion
        #region 3D 체크 박스 체크 변경시 처리하기 - threeDChechBox_CheckedChanged(sender, e)

        /// <summary>
        /// 3D 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void threeDChechBox_CheckedChanged(object sender, EventArgs e)
        {
            this.tChart.Aspect.View3D = this.threeDChechBox.Checked;
        }

        #endregion
        #region 레전드 체크 박스 체크 변경시 처리하기 - legendCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 레전드 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void legendCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.tChart.Legend.Visible = this.legendCheckBox.Checked;
        }

        #endregion
        #region 타이머 틱 처리하기 - timer_Tick(sender, e)

        /// <summary>
        /// 타이머 틱 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void timer_Tick(object sender, EventArgs e)
        {
            ProcessAnimation(this.tChart);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 애니메이션 처리하기 - ProcessAnimation(tChart)

        /// <summary>
        /// 애니메이션 처리하기
        /// </summary>
        /// <param name="tChart">TChart</param>
        private void ProcessAnimation(TChart tChart)
        {
            Random random = new Random();
            double newX;
            double newY;

            tChart.AutoRepaint = false;

            foreach(Series series in tChart.Series)
            {
                while(series.Count > 50)
                {
                    series.Delete(0);
                }

                //if(series.Count > 50)
                //{
                //    series.Delete(0);
                //}

                newX = series.XValues.Last + 1;
                newY = series.YValues.Last + 1000 * random.Next(2) - 500;

                if(Math.Abs(newY) > 1.0e+4)
                {
                    newY = 0.0;
                }

                series.Add(newX,newY);
            }

            tChart.AutoRepaint = true;

            tChart.Refresh();
        }

        #endregion
    }
}